#!/bin/sh

eval `/sbin/ts4800ctl --info`
eval `/sbin/ts4800ctl -T`
eval `/sbin/ts4800ctl -g`
eval `/sbin/xuartctl 2>&1`

s="\033[80D\033[39C "

STR=">> Booted from: "
if [ "$bootdev" == "0x1" ]; then STR=$STR"SD Card"
else STR=$STR"XNAND flash"
fi
STR=$STR"${s}Booted in: $BOOTTIME seconds"
echo -e $STR

STR=">> SBC model number: "
case $model in
	0x4800) hasnand=1 ;;
esac
case $model in
	0x4800) STR=$STR"TS-4800" ;;
	0x4820) STR=$STR"TS-4820" ;;
	*) STR=$STR"$model" ;;
esac
STR=$STR"${s}SBC sub-model number: $submodel"
echo -e $STR

X=`cat /sys/devices/system/cpu/cpu0/cpufreq/cpuinfo_cur_freq`
X=$(($X/1000))
STR=">> CPU clock rate: "$X"MHz"
STR=$STR"${s}RAM size: `dmesg | egrep "Memory:.*total" | sed -e 's/.* = //' -e 's/ total//'`"
echo -e $STR

STR=">> NAND Flash size: 256MB"
STR=$STR"${s}NAND Flash type: XNAND2"
echo -e $STR

STR=">> MAC number: $mac"
STR=$STR"${s}SBC FPGA version: $revision"
echo -e $STR

STR=">> Temperature sensor: $temperature"
STR=$STR"${s}Date and time: `date "+%b %e %Y %T"`"
echo -e $STR

if [ "$model" = "0x4800" ]; then
	let baseboard_rev="$baseboard_model >> 6"
	case $baseboard_rev in
	0) rev=RevA ;;
	1) rev=RevB ;;
	2) rev=RevC ;;
	3) rev=RevD ;;
	esac
	
	case $baseboard_model in
	252) baseboard_model="RHRC"; rev="" ;;
	253) baseboard_model="GS-8110"; rev="" ;;
	254) baseboard_model="Ritec"; rev="" ;;
	*) let baseboard_model="$baseboard_model & 0x3f" ;;
	esac
	
	case $baseboard_model in
	2) baseboard_model="TS-8390 $rev" ;;
	4) baseboard_model="TS-8500 $rev" ;;
	5) baseboard_model="TS-8400 $rev" ;;
	6) baseboard_model="TS-8160 $rev" ;;
	7) baseboard_model="TS-8100 $rev" ;;
	8) baseboard_model="TS-8820 $rev" ;;
	10) baseboard_model="TS-8900 $rev" ;;
	63) baseboard_model="TS-8200" ;;
	*) baseboard_model="$baseboard_model $rev" ;;
	esac
	
	echo -n ">> Base board type: $baseboard_model"
fi

echo -e -n "${s}Reset switch: "
if [ "$resetsw_en" == "0x1" ]; then echo "ON"
else echo "OFF"
fi

VAL=`peekpoke 16 0xb0010016`
MODE1=$((VAL&1))
VAL=$((VAL>>1))
MODE2=$((VAL&1))
echo -n ">> MODE1 bootstrap: "
if [ "$MODE1" == "1" ]; then echo -n "ON"
else echo -n "OFF"
fi
echo -e -n "${s}MODE2 bootstrap: "
if [ "$MODE2" == "1" ]; then echo "ON"
else echo "OFF"
fi

STR=">> XUARTs detected: $xuarts_detected"
STR=$STR"${s}SD Card size: `dmesg|grep 'mmcblk0: mmc0'|cut -d' ' -f4-5`"
echo -e $STR

STR=">> Kernel version: `uname -r | cut -d'-' -f 1`"
STR=$STR"${s}Kernel date: `uname -a | sed 's,PREEMPT ,,' | cut -d' ' -f 6-7,10`"
echo -e $STR

STR=">> ts4800ctl date: `date -r /sbin/ts4800ctl +'%B %d %Y'`"
STR=$STR"${s}canctl date: `cat /sbin/canctl |grep "Copyright (c) Technologic Systems"|cut -d' ' -f6-10`"
echo -e $STR

STR=">> dioctl date: `cat /sbin/dioctl  |grep "Copyright (c) Technologic Systems"|cut -d' ' -f6-10`"
STR=$STR"${s}nandctl date: `date -r /sbin/nandctl +'%B %d %Y'`"
echo -e $STR

STR=">> spictl date: `cat /sbin/spictl  |grep "Copyright (c) Technologic Systems"|cut -d' ' -f6-10`"
STR=$STR"${s}xuartctl date: `cat /sbin/xuartctl  |grep "Copyright (c) Technologic Systems"|cut -d' ' -f6-10`"
echo -e $STR

STR=">> ts.subr date: `date -r /ts.subr +'%B %d %Y'`"
STR=$STR"${s}busybox date: `date -r /bin/busybox +'%B %d %Y'`"
echo -e $STR

STR=">> linuxrc-4800 date: `date -r /linuxrc-4800 +'%B %d %Y'`"
STR=$STR"${s}init-xorgenv date: `date -r /init-xorgenv +'%B %d %Y'`"
echo -e $STR

if [ "$bootdev" == "0x1" ]; then 
	MBRMD5=`(dd if=/dev/mmcblk0 bs=1 count=446|md5sum|cut -d' ' -f1) 2>/dev/null`
else 
	MBRMD5=`(dd if=/dev/nbd0 bs=1 count=446|md5sum|cut -d' ' -f1) 2>/dev/null`
fi
if [ "$MBRMD5" = "349030e2c3b0031b541333daebb363ab" ]; then
	STR=">> MBR date: February 04 2011"
else
	STR=">> MBR date: Unknown"
fi
eval `/sbin/tsversions`
STR=$STR"${s}INITRD date: $initrd"
echo -e $STR

STR=">> Flash root date: $flashrootfs"
STR=$STR"${s}SD rootfs date: $sdrootfs"
echo -e $STR

